@@ -10,26 +10,31 @@ import logging
 import os
 import subprocess
 
-import pkg_resources
-
 log = logging.getLogger(__name__)
 
+
 def get_url(project):
     """Return the URL for the given project.
     """
-    user = os.environ.get('VIRTUALENVWRAPPER_BITBUCKET_USER', os.environ.get('USER'))
+    user = os.environ.get('VIRTUALENVWRAPPER_BITBUCKET_USER',
+                          os.environ.get('USER'))
     if not user:
         log.error('Set USER or VIRTUALENVWRAPPER_BITBUCKET_USER')
         return None
-    url = 'ssh://hg@bitbucket.org/{user}/{project}'.format(user=user, project=project)
+    url = 'ssh://hg@bitbucket.org/{user}/{project}'.format(
+        user=user,
+        project=project,
+    )
     return url
 
+
 def template(args):
     """Clones a BitBucket.org repository into the project directory.
     """
-    project = args[0]
+    project, project_dir = args
     url = get_url(project)
+    outdir = os.path.join(project_dir, project)
     if url:
         log.info('Cloning %s', url)
-        subprocess.call(['hg', 'clone', url, project], shell=False)
+        subprocess.call(['hg', 'clone', url, outdir], shell=False)
     return
